==> hoteldruid-mod-nl_2.2.1-1.zip: nl/funzioni.php <==
<?php

switch ($messaggio) {

case "Nome utente":  				$messaggio = "Gebruikersnaam"; break;
case "minuti":  				$messaggio = "minuten"; break;
case "secondi":  				$messaggio = "seconden"; break;
case "Il database deve essere aggiornato":  	$messaggio = "Database moet geupdate"; break;
case "<div style=\"display: inline; color: red;\">ERRORE</div> di scrittura del file":  		$messaggio = "<div style=\"display: inline; color: red;\">ERROR</div> writing file"; break;
case "Password":  				$messaggio = "Password"; break;
case "Entra":  					$messaggio = "Login"; break;
case "Login per HotelDruid":  			$messaggio = "Login for HotelDruid"; break;
case "Sessione <div style=\"display: inline; color: red;\">scaduta</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Expired</div> session"; break;
case "Nome utente o password <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Incorrect</div> username or password"; break;
case "Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi":	$messaggio = "Excessive number of <div style=\"display: inline; color: red;\">incorrect</div> logins in the last"; break;
case "Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere":	$messaggio = "After an <div style=\"display: inline; color: red;\">incorrect</div> login you must wait"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "Mancano solo":  				$messaggio = "Only"; break;
case "tentativi prima del blocco dei login": 	$messaggio = "attempts remaining before locking the login"; break;
case "Manca solo":  				$messaggio = "Only"; break;
case "tentativo prima del blocco dei login":	$messaggio = "attempt remaining before locking the login"; break;
case "È possibile reimpostare la password dal proprio account di hosting":	$messaggio = "You can reset the password from your hosting account"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-nl_3.0.8-1.zip: nl/funzioni.php <==
<?php

switch ($messaggio) {

case "Nome utente":  				$messaggio = "Gebruikersnaam"; break;
case "minuti":  				$messaggio = "minuten"; break;
case "secondi":  				$messaggio = "seconden"; break;
case "Il database deve essere aggiornato":  	$messaggio = "Database moet geupdate"; break;
case "<div style=\"display: inline; color: red;\">ERRORE</div> di scrittura del file":  		$messaggio = "<div style=\"display: inline; color: red;\">ERROR</div> writing file"; break;
case "Password":  				$messaggio = "Password"; break;
case "Entra":  					$messaggio = "Login"; break;
case "Login per HotelDruid":  			$messaggio = "Login for HotelDruid"; break;
case "Sessione <div style=\"display: inline; color: red;\">scaduta</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Expired</div> session"; break;
case "Nome utente o password <div style=\"display: inline; color: red;\">errati</div>":	$messaggio = "<div style=\"display: inline; color: red;\">Incorrect</div> username or password"; break;
case "Numero eccesivo di login <div style=\"display: inline; color: red;\">errati</div> negli ultimi":	$messaggio = "Excessive number of <div style=\"display: inline; color: red;\">incorrect</div> logins in the last"; break;
case "Dopo un login <div style=\"display: inline; color: red;\">errato</div> si devono attendere":	$messaggio = "After an <div style=\"display: inline; color: red;\">incorrect</div> login you must wait"; break;
case "Aggiorna":  				$messaggio = "Update"; break;
case "Mancano solo":  				$messaggio = "Only"; break;
case "tentativi prima del blocco dei login": 	$messaggio = "attempts remaining before locking the login"; break;
case "Manca solo":  				$messaggio = "Only"; break;
case "tentativo prima del blocco dei login":	$messaggio = "attempt remaining before locking the login"; break;
case "È possibile reimpostare la password dal proprio account di hosting":	$messaggio = "You can reset the password from your hosting account"; break;
case "orario del server":  			$messaggio = "server time"; break;
case "Avviso":  				$messaggio = "Warning"; break;
case "Mancano meno di":  			$messaggio = "Less than"; break;
case "giorni alla scadenza dell'account":  	$messaggio = "days left until the account expires"; break;
case "Numero eccesivo di sessioni <span style=\"color: red;\">errate</span> originate dal tuo indirizzo IP negli ultimi":	$messaggio = "Excessive number of <span style=\"color: red;\">incorrect</span> sessions from your IP address in the last"; break;
case "È possibile che qualcuno dalla tua stessa rete stia tentando di rubare il tuo accesso":	$messaggio = "It is possible that someone from your same network is trying to steal your access"; break;
case "Non hai i privilegi per accedere a questa pagina":	$messaggio = "You do not have privileges to access this page"; break;
case "Accedi come utente amministratore o altro utente abilitato":	$messaggio = "Log in as an administrator user or another authorized user"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
